@@ -13,7 +13,8 @@ from jsonrpcclient import logger
 class Server:
     """This class acts as the remote server"""
 
-    def __init__(self, endpoint):
+    def __init__(self, endpoint, auth=None):
+        self.auth = auth
         self.endpoint = endpoint
 
     def __getattr__(self, name):
@@ -54,7 +55,7 @@ class Server:
         """
 
         # Log the request
-        logger.debug('--> '+json.dumps(request_dict))
+        logger.info('--> '+json.dumps(request_dict))
 
         try:
             # Send the message
@@ -63,7 +64,8 @@ class Server:
                 headers={
                     'Content-Type': 'application/json; charset=utf-8'
                 },
-                json=request_dict
+                json=request_dict,
+                auth=self.auth
             )
 
         except (requests.exceptions.InvalidSchema,
@@ -72,13 +74,13 @@ class Server:
 
         if len(r.text):
             # Log the response
-            logger.debug('<-- '+str(r.status_code)+' '+r.text \
+            logger.info('<-- {} {}'.format(r.status_code, r.text) \
                 .replace("\n", '') \
                 .replace('  ', ' ') \
                 .replace('{ ', '{'))
 
         else:
-            logger.debug('<-- {} {}'.format(r.status_code, r.reason))
+            logger.info('<-- {} {}'.format(r.status_code, r.reason))
 
             # Raise exception the HTTP status code was not 200, and there was no
             # response body, because this should be handled.
